@@ -7,7 +7,7 @@
 # Distributed under the terms of the GPL
 ###############################################################################
 ###############################################################################
-# Version 0.8.1
+# Version 0.8.3
 ###############################################################################
 ###############################################################################
 # This program recursively downloads Web sites, as it goes, it changes absolute
@@ -111,7 +111,7 @@ proc InitializeDownload {url} {
         if {$fileName==""} {
             set isHtml 1
         } else {
-            set isHtml [regexp -nocase {html?$} $fileName]
+            set isHtml [regexp -nocase {\.html?$} $fileName]
         }
         if {$siteUrl(prot)==""} {
             set siteUrl(prot) http
@@ -145,6 +145,7 @@ proc InitializeDownload {url} {
     }
 
     if {($result==1)&&($isHtml==0)} {
+        set localFileName [UrlToFile $url]
         if {![file exists $localFileName.html]} {
             file rename -force $localFileName $localFileName.html
             exec touch $localFileName
@@ -350,7 +351,7 @@ proc ChangeLinksToChoose {referer text map} {
     $text delete 1.0 end
 
     set file [lindex [array get filesDone] 0]
-    unset filesDone
+    catch {unset filesDone}
     set refererFile [UrlToFile $referer]
     catch {file rename -force $refererFile.orig $refererFile}
     Preprocessing $referer
@@ -378,7 +379,7 @@ proc LinksToChoose {text map} {
     if {$map==1} {
         set HtmlParser::nLinks $siteIndex
     }
-
+puts "$HtmlParser::nLinks"
     for {set i 1;set pre ""} {$i<$HtmlParser::nLinks} {incr i} {
         checkbutton $text.enlaces$i -variable linksOk($i) -background $color
         set linksOk($i) 1
@@ -395,7 +396,11 @@ proc LinksToChoose {text map} {
             set description [HtmlParser::TidyDescription $siteMap($i,2)]
         }
         if {[regexp {^[\ \t]*$} $description]} {
-            set description $HtmlParser::linkFile($i)
+            if {$map==0} {
+                set description $HtmlParser::linkFile($i)
+            } else {
+                set description $siteMap($i,1)
+            }
         }
         $text.enlaces$i configure -text $pre$description
 
@@ -781,7 +786,7 @@ proc Download {enlace madre sufix} {
             set enlace   $meta(relocate)
             set relocated(ok) 1
             if {[file exists $fileName]} {
-                if {([regexp -nocase {html?$} $fileName])||([file exists $fileName.html])} {
+                if {([regexp -nocase {\.html?$} $fileName])||([file exists $fileName.html])} {
                     set isHtml 1
                 } else {
                     set isHtml 0
@@ -893,9 +898,9 @@ proc ChangePage {url} {
         set newLink [HtmlParser::CompleteUrl $link $url]
 
         # First we prepare the link taken from the page
-        regsub {^\.\.}    $link {\\\.\\\.} link
-        regsub {^\.}      $link {\\\.}     link
-        regsub -all {\*}  $link {\\*}      link
+        regsub {^\.\.}    $link {\\.\\.} link
+        regsub {^\.}      $link {\\.}    link
+        regsub -all {\*}  $link {\\*}    link
 
         # Now deal with the complete link to get what will bve put in the
         # changed page
@@ -1055,7 +1060,7 @@ proc ControlDownloading {urlList referer level {externalLevel 0}} {
             set invokeSed 1
         }
 
-        if [regexp -nocase {htm|html} [file extension $fileName]] {
+        if [regexp -nocase {\.html?} [file extension $fileName]] {
             set sufijo 1
         } else {
             set sufijo 0
@@ -1091,7 +1096,7 @@ proc ControlDownloading {urlList referer level {externalLevel 0}} {
                 set pattern "(?:$directories(base))(.*)"
                 regexp $pattern $oldLink nada oldLink
                 regexp $pattern $newLink nada newLink
-                set sufix [regexp -nocase {html|htm} \
+                set sufix [regexp -nocase {\.html?} \
                         [file extension $newLink]]
                 if {$isHtml($j)==4} {
                     set isHtml($j) 1
@@ -1110,25 +1115,11 @@ proc ControlDownloading {urlList referer level {externalLevel 0}} {
             break
         }
         if {$options(pauseFile)==1} {
-            set windowState [wm state .bajando]
-            if {$windowState=="iconic"} {
-                wm deiconify .bajando
-            }
-            wm withdraw .bajando
-            tk_messageBox -title $labelTitles(paused) -icon info -type ok \
-                    -message $labelMessages(paused)
-            tkwait variable options(pauseFile)
-            wm deiconify .bajando
-            if {$windowState=="iconic"} {
-                wm iconify .bajando
-            }
-
+            Ventana::Pause file
         }
     }
     if {$options(pausePage)==1} {
-        tk_messageBox -title $labelTitles(paused) -icon info -type ok \
-                -message $labelMessages(paused)
-        tkwait variable options(pausePage)
+        Ventana::Pause page
     }
 
     if {$invokeSed==1} {
@@ -1280,7 +1271,7 @@ proc EnterUrl {} {
     bind $pagina.entry <Return>   "$empezar invoke"
     bind $pagina.entry <KP_Enter> "$empezar invoke"
     bind $pagina.entry <Button-3> "
-        $marco.pagina.eentry insert insert \[ReadSel\]
+        $pagina.entry insert insert \[ReadSel\]
     "
     bind $intro    <Escape>   "$cancelar invoke"
 
@@ -1335,7 +1326,7 @@ proc EnterUrl {} {
         return
     }
     set localFileName [UrlToFile $requestedUrl]
-    if {($options(levels)==0)||(![regexp -nocase {html?$} $localFileName])} {
+    if {($options(levels)==0)||(![regexp -nocase {\.html?$} $localFileName])} {
         tk_messageBox -icon info -title $labelTitles(theEnd) -type ok \
                 -message $labelMessages(theEnd)
         set getleftState(downloading) 0
@@ -1353,24 +1344,26 @@ proc EnterUrl {} {
     if {$chosen==1} {
         ControlDownloading [PrepareDownloading 0] $requestedUrl 1
 
-        set options(stopFile)           0
-        set options(stopPage)           0
-        set options(pauseFile)          0
-        set options(pausePage)          0
-        set getleftState(filesChosen)   0
-
         if [catch {wm withdraw .bajando} error] {
             if {$::DEBUG==1} {
                 tk_messageBox -title Error -icon error -message $error -type ok
             }
         }
+        update
         if {$options(map)==0} {
             tk_messageBox -icon info -title $labelTitles(theEnd) -type ok \
                     -message $labelMessages(theEnd)
             if {$getleftState(errorFound)==1} {
                 ::Herramientas::ShowErrorLog
             }
+        } else {
+            return $requestedUrl
         }
+        set options(stopFile)           0
+        set options(stopPage)           0
+        set options(pauseFile)          0
+        set options(pausePage)          0
+        set getleftState(filesChosen)   0
     }
     catch "unset filesDone"
     set getleftState(downloading) 0
@@ -1412,16 +1405,19 @@ proc GetSiteMap {} {
         for {set i 1} {$i<$siteIndex} {incr i} {
             if {$linksOk($i)==1} {
                 set enlace $siteMap($i,1)
-                set filename [file root $fichero]
+                set filename [UrlToFile $enlace]
                 if {[file exists $filename]} {
                     continue
                 } else {
-                    set isHtml [regexp -nocase {html?} $filename]
-                    Download $siteUrl(www)$enlace "-" $isHtml
-               }
+                    set isHtml [regexp -nocase {\.html?} $filename]
+                    Download $enlace "-" $isHtml
+                }
                 if {$options(stopFile)==1} {
                     break
-               }
+                }
+                if {$options(pauseFile)==1} {
+                    Ventana::Pause file
+                }
             }
         }
         tk_messageBox -icon info -title $labelTitles(theEnd) -type ok \
@@ -1436,7 +1432,12 @@ proc GetSiteMap {} {
     if {$getleftState(errorFound)==1} {
         ::Herramientas::ShowErrorLog
     }
-    set options(levels) $tmp
+    set options(levels)             $tmp
+    set options(stopFile)           0
+    set options(stopPage)           0
+    set options(pauseFile)          0
+    set options(pausePage)          0
+    set getleftState(filesChosen)   0
 
     return
 }
@@ -2007,7 +2008,7 @@ if {![winfo exists .menus]} {
     ReadSupportedLang
     ReadLangFile en
 
-    wm title . "Getleft v 0.8.1"
+    wm title . "Getleft v 0.8.3"
     if [regexp {Windows} $tcl_platform(os)] {
          wm geometry . 300x25
     } else {
