@@ -1,12 +1,14 @@
 ###############################################################################
 ###############################################################################
 ##                        Herramientas.tcl
-##
+###############################################################################
+###############################################################################
 ## Includes procedures to implement the commands in the 'Tools' and 'Options'
 ## menus.
-##
-## (c) 1999 Andrs Garca Garca.
-## Distributed under the term of the GNU licence
+###############################################################################
+###############################################################################
+## (c) 1999-2000 Andrs Garca Garca. andresgarci@retemail.es
+## Distributed under the terms of the GPL licence
 ###############################################################################
 ###############################################################################
 
@@ -26,15 +28,15 @@ namespace eval Herramientas {
 #    1: if cancelled
 ###############################################################################
 proc ExtensionDialog {title} {
-    variable botonPulsado
-    global coord labelButton labelTitles
+    global labelButtons labelTitles done2
 
-    fijar_coordenadas
+    set coord(x) [winfo rootx .]
+    set coord(y) [winfo rooty .]
 
     set ext [toplevel .extDialog]
     wm title $ext $title
     wm resizable $ext 0 0
-    wm geometry $ext +[expr $coord(x)+100]+[expr $coord(y)+50]
+    wm geometry $ext +[expr $coord(x)+100]+[expr $coord(y)+15]
 
     set marcoExt [frame $ext.marcoext]
     set marcoRel [frame $marcoExt.marcoint -bd 2 -relief groove]
@@ -85,13 +87,12 @@ proc ExtensionDialog {title} {
         }
     }
 
-    set aceptar  [button $marcoBot.aceptar  -text $labelButton(ok)    \
-		-width 8 -command "set Herramientas::botonPulsado 1"]
-    set cancelar [button $marcoBot.cancelar -text $labelButton(cancel) \
-		-width 8 -command "set Herramientas::botonPulsado 0"]
+    set aceptar  [button $marcoBot.aceptar  -textvariable labelButtons(ok)    \
+		-width 8 -command "set done2 1"]
+    set cancelar [button $marcoBot.cancelar -textvariable labelButtons(cancel)\
+		-width 8 -command "set done2 0"]
 
-    bind  $aceptar  <Key-Return> "$aceptar  invoke"
-    bind  $cancelar <Key-Return> "$cancelar invoke"
+    bind $ext <Escape> "$cancelar invoke"
 
     pack $marcoExt -ipadx 10 -ipady 5
     pack $marcoRel -ipadx 15 -side bottom
@@ -118,9 +119,11 @@ proc ExtensionDialog {title} {
     pack $marcoBot
     pack $aceptar $cancelar -side left -pady 5 -padx 5
 
-    tkwait variable Herramientas::botonPulsado
+    grab $ext
+    tkwait variable done2
+    grab release $ext
     destroy $ext
-    if {$botonPulsado==0} {
+    if {$done2==0} {
         return 1
     }
 
@@ -128,14 +131,14 @@ proc ExtensionDialog {title} {
 }
 
 ###############################################################################
-# PurgarFicherosDir
+# PurgeFilesDir
 #    Sweeps a directory turning files to size 0
 #
 # Parameters:
 #    dir: directory to be processed
 #    purgarCmd: extensions of the files to minimize
 ###############################################################################
-proc PurgarFicherosDir {dir purgarCmd} {
+proc PurgeFilesDir {dir purgarCmd} {
     global dirGetleft tcl_platform
 
     cd $dir
@@ -149,7 +152,7 @@ proc PurgarFicherosDir {dir purgarCmd} {
         if {$estado(size)!=0} {
             file delete -force $file
             if [regexp {Windows} $tcl_platform(os)] {
-                exec [file join $dirGetleft touch] $file
+                exec [file join $dirGetleft(main) touch] $file
             } else {
                 exec touch $file
             }
@@ -166,25 +169,29 @@ proc PurgarFicherosDir {dir purgarCmd} {
 
     foreach dir $directorios {
 	  update
-        PurgarFicherosDir $dir $purgarCmd
+        PurgeFilesDir $dir $purgarCmd
         cd ..
     }
     return
 }
 
 ###############################################################################
-# PurgarFicheros
+# PurgeFiles
 #    The procedures takes care of recursively clean directories of files
 #    with certain extensions *.jpg, *.gif, etc.
 ###############################################################################
-proc PurgarFicheros {} {
+proc PurgeFiles {} {
     global labelTitles labelMessages
 
+    if [winfo exists .extDialog] {
+        return
+    }
+
     if {[ExtensionDialog $labelTitles(purge)]==1} {
         return
     }
 
-    set dir [Dialogos::SeleccionarDirectorio]
+    set dir [Dialogos::SelectDirectory]
     if {![string compare $dir ""]} {
         return
     }
@@ -194,7 +201,7 @@ proc PurgarFicheros {} {
         append purgarCmd $::bot($i) " "
     }
 
-    PurgarFicherosDir $dir $purgarCmd
+    PurgeFilesDir $dir $purgarCmd
 
     tk_messageBox -title $labelTitles(theEnd) -icon info \
         -message $labelMessages(purged)
@@ -205,13 +212,13 @@ proc PurgarFicheros {} {
 }
 
 ###############################################################################
-# RestaurarOriginalesDir
+# RestoreOriginalsDir
 #    Recursively restores the original files.
 #
 # Parameter:
 #    dir: directory in which it will begin to restore.
 ###############################################################################
-proc RestaurarOriginalesDir {dir} {
+proc RestoreOriginalsDir {dir} {
 
     cd $dir
     set directorio [glob -nocomplain *.orig]
@@ -226,28 +233,28 @@ proc RestaurarOriginalesDir {dir} {
             lappend directorios $fichero
         }
     }
- 
+
     foreach dir $directorios {
-	    RestaurarOriginalesDir $dir
+	    RestoreOriginalsDir $dir
         cd ..
     }
     return
 }
 
 ###############################################################################
-# RestaurarOriginales
+# RestoreOriginals
 #    Starts the process of restoring the original files downloaded from Web
 #    pages.
 ###############################################################################
-proc RestaurarOriginales {} {
+proc RestoreOriginals {} {
     global labelTitles labelMessages
 
-    set dir [Dialogos::SeleccionarDirectorio]
+    set dir [Dialogos::SelectDirectory]
     if {![string compare $dir ""]} {
         return
     }
     set dirTmp [pwd]
-    RestaurarOriginalesDir $dir
+    RestoreOriginalsDir $dir
 
     tk_messageBox -title $labelTitles(theEnd) -icon info \
             -message $labelMessages(restored)
@@ -262,19 +269,23 @@ proc RestaurarOriginales {} {
 #    Allows the user to enter his proxy data.
 ###############################################################################
 proc ConfProxy {} {
-    global ok coord opciones labelButton labelTitles
+    global done options labelButtons labelTitles
     variable ip
     variable n
-    variable p
 
-    fijar_coordenadas
+    if [winfo exists .proxy] {
+        return
+    }
+
+    set coord(x) [winfo rootx .]
+    set coord(y) [winfo rooty .]
 
     set proxy [toplevel .proxy]
     wm title $proxy $labelTitles(proxy)
     wm resizable $proxy 0 0
     wm geometry  $proxy +[expr $coord(x)+100]+[expr $coord(y)+50]
 
-    set ok 0
+    set done 0
 
     set marcoEx [frame $proxy.marcoEx]
     set marco   [frame $marcoEx.marco -bd 2 -relief groove]
@@ -291,13 +302,16 @@ proc ConfProxy {} {
     set colon  [label $marcoIn.colon  -text : -width 2]
 
     set botones  [frame  $proxy.botones]
-    set aceptar  [button $botones.aceptar  -text $labelButton(ok)     \
-            -width 8 -command {set ok 1}]
-    set cancelar [button $botones.cancelar -text $labelButton(cancel) \
-            -width 8 -command {set ok 0}]
+    set borrar   [button $botones.borrar   -textvariable labelButtons(clear) \
+            -width 6 -command {set done 2}]
+    set aceptar  [button $botones.aceptar  -textvariable labelButtons(ok)    \
+            -width 6 -command {set done 1}]
+    set cancelar [button $botones.cancelar -textvariable labelButtons(cancel)\
+            -width 6 -command {set done 0}]
 
     pack $cancelar -side right -padx 9 -pady 5
     pack $aceptar  -side right -pady 5
+    pack $borrar   -side right -padx 9
     pack $botones  -side bottom -fill x
 
     pack $ip(1) $punto1 $ip(2) $punto2 $ip(3) $punto3 $ip(4) $colon $ip(5) -side left
@@ -307,12 +321,11 @@ proc ConfProxy {} {
 
     focus $ip(1)
 
-    bind $aceptar  <Return> "$aceptar invoke"
-    bind $cancelar <Return> "$cancelar invoke"
-
+    bind $proxy <Escape> "$cancelar invoke"
     for {set i 1;set n 2} {$i<6} {incr i;incr n} {
         if {$i!=5} {
-            bind $ip($i) <Return> "focus $ip($n)"
+            bind $ip($i) <Return>   "focus $ip($n)"
+            bind $ip($i) <KP_Enter> "focus $ip($n)"
             bind $ip($i) <Key-Right> {
                 %W selection range 0 0
                 set indice [%W index insert]
@@ -352,6 +365,9 @@ proc ConfProxy {} {
             bind $ip($i) <Return> "
                 focus $aceptar
             "
+            bind $ip($i) <KP_Enter> "
+                focus $aceptar
+            "
         }
         if {$i!=1} {
             bind $ip($i) <Key-Left> {
@@ -364,9 +380,9 @@ proc ConfProxy {} {
         bind $ip($i) <FocusIn> "$ip($i) selection range 0 end"
     }
 
-    if [info exists opciones(dirProxy)] {
+    if [info exists options(dirProxy)] {
         regexp {([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?::)(.*)} \
-                 $opciones(dirProxy) nada ip1 ip2 ip3 ip4 ip5
+                 $options(dirProxy) nada ip1 ip2 ip3 ip4 ip5
         $ip(1) insert insert $ip1
         $ip(2) insert insert $ip2
         $ip(3) insert insert $ip3
@@ -374,14 +390,20 @@ proc ConfProxy {} {
         $ip(5) insert insert $ip5
     }
 
-    tkwait variable ok
+    tkwait variable done
 
-    if {$ok==1} {
+    if {$done==1} {
         for {set i 1} {$i<6} {incr i} {
             set dirProxy($i) [$ip($i) get]
         }
-        set opciones(dirProxy) "$dirProxy(1).$dirProxy(2).$dirProxy(3).$dirProxy(4):$dirProxy(5)"
-        GuardarConfig
+        set options(dirProxy) "$dirProxy(1).$dirProxy(2).$dirProxy(3).$dirProxy(4):$dirProxy(5)"
+        SaveConfig
+    } elseif {$done==2} {
+        for {set i 1} {$i<6} {incr i} {
+            $ip($i) delete 0 end
+        }
+        catch {unset options(dirProxy)}
+        SaveConfig
     }
 
     destroy $proxy
@@ -399,13 +421,17 @@ proc ConfProxy {} {
 #    used to filter the links.
 ###############################################################################
 proc FilterFiles {} {
-    global opciones labelTitles labelMessages
+    global options labelTitles labelMessages
+
+    if [winfo exists .extDialog] {
+        return
+    }
 
     if {[ExtensionDialog $labelTitles(exclude)]==1} {
         return
     }
 
-    set opciones(onlyHtml) 0
+    set options(onlyHtml) 0
 
     for {set i 1;set filter ""} {$i<10} {incr i} {
         if {$::bot($i)!=""} {
@@ -415,7 +441,7 @@ proc FilterFiles {} {
     regsub -all {(\*\.)} $filter {} filter
     regexp {(.*)(\|)} $filter nada filter
 
-    set opciones(filter) $filter
+    set options(filter) $filter
 
     return
 }
@@ -429,35 +455,38 @@ proc FilterFiles {} {
 #    link: link that we where trying to download
 ###############################################################################
 proc ErrorLog {file link} {
-    global dirGetleft env tcl_platform errorsFound
-    global labelDialogs labelMonths
+    global dirGetleft env tcl_platform getleftState
+    global labelDialogs labelMonths supportedLang options
+    global errorCode
 
     if [regexp {Windows} $tcl_platform(os)] {
-        set errorLog [file join "$dirGetleft" Geterror.log]
+        set errorLog [file join "$dirGetleft(main)" Geterror.log]
     } else {
         set errorLog [file join $env(HOME) Geterror.log]
     }
 
-    set handle [open $errorLog a+]
+    set handle  [open $errorLog a+]
+    fconfigure $handle -encoding $supportedLang($options(lang))
+
     set seconds [clock seconds]
     set month $labelMonths([clock format $seconds -format %B])
+
     puts $handle "[clock format $seconds -format "%d-$month-%Y -- %H:%M"]"
     puts $handle "$labelDialogs(errorLink) $link"
     puts $handle "$labelDialogs(errorFile) [file root $file]"
-    if {$Ventana::Rizo::meta(codigo)>=400} {
-        puts -nonewline $handle  \
-                "$labelDialogs(errorCode) $::Ventana::Rizo::meta(codigo), "
-        puts $handle "$labelDialogs(errorMess) $::Ventana::Rizo::meta(error)"
-    } else {
-        puts -nonewline $handle  \
+
+#puts "En ErrorLog: $errorCode"
+    if {[lindex $errorCode 0]!="Getleft"} {
+        puts -nonewline $handle \
                 "$labelDialogs(errorCode) $::Ventana::Rizo::curlError, "
-        puts $handle "$labelDialogs(errorMess) $::Ventana::Rizo::mensaje_error"
+        puts $handle "$labelDialogs(errorMess) $::Ventana::Rizo::errorMessage"
+    } else {
+        puts $handle "$labelDialogs(errorMess) [lindex $errorCode 1]"
     }
+
     puts $handle ""
-
     close $handle
-
-    set errorsFound 1
+    set getleftState(errorFound) 1
 
     return
 }
@@ -470,7 +499,7 @@ proc EraseErrorLog {} {
     global dirGetleft env tcl_platform
 
     if [regexp {Windows} $tcl_platform(os)] {
-        set errorLog [file join "$dirGetleft" Geterror.log]
+        set errorLog [file join "$dirGetleft(main)" Geterror.log]
     } else {
         set errorLog [file join $env(HOME) Geterror.log]
     }
@@ -490,13 +519,13 @@ proc ShowErrorLog {} {
     global labelDialogs labelMonths labelTitles
 
     if [regexp {Windows} $tcl_platform(os)] {
-        set errorLog [file join "$dirGetleft" Geterror.log]
+        set errorLog [file join "$dirGetleft(main)" Geterror.log]
     } else {
         set errorLog [file join $env(HOME) Geterror.log]
     }
 
     if [file exists $errorLog] {
-        Ayuda::CrearVentana $labelTitles(errorLog) $errorLog 1
+        Ayuda::DefineWindow $labelTitles(errorLog) $errorLog 1
     }
     return
 }
