@@ -16,18 +16,21 @@ variable errorMessage ""
 variable meta
 variable curlReport
 
-# In version 6.4 curl changed the format of its report, this kludge deals
-# with it.
+# In version 6.4 and then again in version 6.5 curl changed the format of its
+# report, this kludge deals with it.
 
-catch {exec curl -V} version
-set version [lindex $version 1]
-regexp {^[0-9]\.[0-9]} $version version
-if {$version<6.4} {
+catch {exec curl -V} curlVersion
+set version [lindex $curlVersion 1]
+regexp {[0-9]\.[0-9]} $curlVersion curlVersion
+if {$curlVersion<6.4} {
     set leftIndex  4
     set speedIndex 6
-} else {
+} elseif {$curlVersion<6.5} {
     set leftIndex  6
     set speedIndex 7
+} else {
+    set leftIndex  10
+    set speedIndex 11
 }
 
 ##############################################################################
@@ -178,6 +181,7 @@ proc Lector {pipe tipo} {
     variable workaround
     variable speedIndex
     variable leftIndex
+    variable curlVersion
     global errorCode getleftState
 
     if {($tipo=="stopNow")||($getleftState(downloading)==0)} {
@@ -200,7 +204,7 @@ proc Lector {pipe tipo} {
                 if {$::DEBUG==1} {
                     if {$tipo!="dat"} {
                         tk_messageBox -icon error -title error \
-                                message "Error 18 en el cuerpo"
+                                -message "Error 18 en el cuerpo"
                     }
                 }
                 set curlError 0
@@ -216,6 +220,9 @@ proc Lector {pipe tipo} {
     }
 
     if {[gets $pipe line]>=0} {
+        if {$::DEBUG==1} {
+#            puts $line
+        }
         if {[string first curl $line]!=-1} {
             set Ventana::Rizo::errorMessage $line
             return
@@ -226,9 +233,6 @@ proc Lector {pipe tipo} {
                 set workaround 1
                 return
             }
-            if {$::DEBUG==1} {
-#                puts $line
-            }
             if [regexp -nocase {^(?:HTTP/)([0-9].[0-9])(?:\ )([0-9]*)(?:\ )(.*)} \
                     $line nada meta(versionServer) meta(code) meta(error)] {
                 if {$meta(code)>=400} {
@@ -252,8 +256,9 @@ proc Lector {pipe tipo} {
                 return
             }
             if {$curlReport(long)==1} {
-                set curlReport(percentage) [lindex $line 0]
                 set curlReport(speed)  [lindex $line $speedIndex]
+                if {$curlReport(speed)==""} return
+                set curlReport(percentage) [lindex $line 0]
             } else {
                 regexp {(^.*?)(?: )(?:.*\()(.*)( )} $line \
                         nada curlReport(gotBytes) curlReport(speed)
@@ -275,13 +280,18 @@ proc Lector {pipe tipo} {
                         "[format "%.2f" [expr $curlReport(gotBytes)/1048576.0]] M"
                 }
             }
-            if {![regexp {/} $curlReport(speed)]} {
-                if {($curlReport(speed)>512)} {
-                    set curlReport(speed) \
-                        "[format "%.2f" [expr $curlReport(speed)/1024.0]] k/s"
-                } else {
-                    set curlReport(speed) \
-                        "[format "%.2f" $curlReport(speed)] bytes/s"
+
+            if [regexp {k$} $curlReport(speed)] {
+                set curlReport(speed) $curlReport(speed)/s
+            } else {
+                if {![regexp {/} $curlReport(speed)]} {
+                    if {($curlReport(speed)>512)} {
+                        set curlReport(speed) \
+                            "[format "%.2f" [expr $curlReport(speed)/1024.0]] k/s"
+                    } else {
+                        set curlReport(speed) \
+                            "[format "%.2f" $curlReport(speed)] bytes/s"
+                    }
                 }
             }
             if {$curlReport(long)==1} {
