@@ -13,6 +13,36 @@ namespace eval Ventana {
 
 source [file join "$dirGetleft(scripts)" Rizo.tcl]
 
+###############################################################################
+# PauseDownloading
+#    Pauses the downloading according to the menu entries.
+#
+# Parameter
+#    which: either 'file' or 'page'
+###############################################################################
+proc Pause {which} {
+    global options labelTitles labelMessages
+
+    set windowState [wm state .bajando]
+    if {$windowState=="iconic"} {
+        wm deiconify .bajando
+    }
+    wm withdraw .bajando
+    tk_messageBox -title $labelTitles(paused) -icon info -type ok \
+         -message $labelMessages(paused)
+    if {$which=="file"} {
+        tkwait variable options(pauseFile)
+    } else {
+        tkwait variable options(pausePage)
+    }
+    wm deiconify .bajando
+    if {$windowState=="iconic"} {
+        wm iconify .bajando
+    }
+
+    return
+}
+
 ###############################################################################
 # CancelDownloading
 #    This procedure is invoked from the downloading window when you click on
@@ -64,6 +94,13 @@ proc CancelDownloading {{skip {} }} {
 #    La cadena recortada
 ###############################################################################
 proc RecortarCadena {cadena long} {
+    variable window
+
+#puts "Fuente usada: [set font [$window(dir) cget -font]]"
+#set cadenaBase "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
+#puts "Longitud base: [font measure $font -displayof .bajando $cadenaBase]"
+#puts "Cadena: $cadena"
+#puts "Longitud de la cadena: [font measure $font -displayof .bajando $cadena]"
 
     set longitud_cadena [string length $cadena]
     if {$longitud_cadena>$long} {
@@ -246,6 +283,7 @@ proc FileDownloading {fichero enlace madre} {
     global Ventana::Rizo::curlReport
 
     if {$getleftState(downloading)==0} {
+puts "Pues no bajamos nada"
         return
     }
 
@@ -363,6 +401,7 @@ proc BarUpdate {barra} {
             -fill black -anchor c]
     set dos [$barra.lienzo2 create text 134.5 7 -text $curlReport(percentage)% \
             -fill white -anchor c]
+
     if {$curlReport(pause)==0} {
         if {($curlReport(end)==0) && ($curlReport(stop)!=1)} {
             set afterId [after 1000 Ventana::BarUpdate $barra]
